@@ -1,7 +1,7 @@
 /* -*- Mode: C; tab-width: 4 -*- */
 /* bat --- bouncing bats */
 
-#if !defined( lint ) && !defined( SABER )
+#if 0
 static const char sccsid[] = "@(#)bat.c	5.00 2000/11/01 xlockmore";
 
 #endif
@@ -27,7 +27,7 @@ static const char sccsid[] = "@(#)bat.c	5.00 2000/11/01 xlockmore";
  * 18-Sep-1995: 5 bats now in color <patol@info.isbiel.ch>
  * 20-Sep-1994: 5 bats instead of bouncing balls, based on bounce.c
  *              <patol@info.isbiel.ch>
- * 02-Sep-1993: bounce version David Bagley <bagleyd@tux.org>
+ * 02-Sep-1993: bounce version David Bagley <bagleyd AT verizon.net>
  * 1986: Sun Microsystems
  */
 
@@ -59,33 +59,32 @@ static const char sccsid[] = "@(#)bat.c	5.00 2000/11/01 xlockmore";
  */
 
 #ifdef STANDALONE
-#define MODE_bat
-#define PROGCLASS "Bat"
-#define HACK_INIT init_bat
-#define HACK_DRAW draw_bat
-#define bat_opts xlockmore_opts
-#define DEFAULTS "*delay: 100000 \n" \
- "*count: -8 \n" \
- "*size: 0 \n" \
- "*ncolors: 200 \n" \
- "*verbose: False \n"
+# define MODE_bat
+# define DEFAULTS	"*delay: 100000 \n" \
+			"*count: -8 \n" \
+			"*size: 0 \n" \
+			"*ncolors: 200 \n" \
+			"*verbose: False \n" \
+
+# define reshape_bat 0
+# define bat_handle_event 0
 #include "xlockmore.h"		/* in xscreensaver distribution */
 #else /* STANDALONE */
-#include "xlock.h"		/* in xlockmore distribution */
-#include "vis.h"
-#include "color.h"
+# include "xlock.h"		/* in xlockmore distribution */
+# include "vis.h"
+# include "color.h"
+# include "iostuff.h"
 #endif /* STANDALONE */
-#include "iostuff.h"
 
 #ifdef MODE_bat
 
-ModeSpecOpt bat_opts =
+ENTRYPOINT ModeSpecOpt bat_opts =
 {0, (XrmOptionDescRec *) NULL, 0, (argtype *) NULL, (OptionStruct *) NULL};
 
 #ifdef USE_MODULES
-const ModStruct bat_description =
+ENTRYPOINT ModStruct bat_description =
 {"bat", "init_bat", "draw_bat", "release_bat",
- "refresh_bat", "init_bat", (char *) NULL, &bat_opts,
+ "refresh_bat", "init_bat", "free_bat", &bat_opts,
  100000, -8, 1, 0, 64, 1.0, "",
  "Shows bouncing flying bats", 0, NULL};
 
@@ -106,6 +105,7 @@ const ModStruct bat_description =
 #include "bitmaps/bat-3.xbm"
 #include "bitmaps/bat-4.xbm"
 
+#ifndef STANDALONE
 /* aliases for vars defined in the bitmap file */
 #define BAT_WIDTH     image_width
 #define BAT_HEIGHT    image_height
@@ -118,6 +118,7 @@ const ModStruct bat_description =
 #include "bat.xpm"
 #define DEFAULT_XPM 1
 #endif
+#endif
 
 #define MAX_STRENGTH 24
 #define FRICTION 15
@@ -220,13 +221,13 @@ checkCollision(bouncestruct * bp, int a_bat)
 					bp->bats[i].spindir = 0;
 				} else
 					bp->bats[i].spindelay = (int) ((double) M_PI *
-								       bp->avgsize / (ABS(bp->bats[i].vang))) + 1;
+							bp->avgsize / (ABS(bp->bats[i].vang))) + 1;
 				if (!bp->bats[a_bat].vang) {
 					bp->bats[a_bat].spindelay = 1;
 					bp->bats[a_bat].spindir = 0;
 				} else
 					bp->bats[a_bat].spindelay = (int) ((double) M_PI *
-									   bp->avgsize / (ABS(bp->bats[a_bat].vang))) + 1;
+							bp->avgsize / (ABS(bp->bats[a_bat].vang))) + 1;
 				return;
 			}
 		}
@@ -244,7 +245,7 @@ drawbat(ModeInfo * mi, batstruct * bat)
 		if (bat->xlast != -1) {
 			XSetForeground(display, bp->backGC, bp->black);
 			XFillRectangle(display, window, bp->backGC,
-				     bat->xlast, bat->ylast, bp->xs, bp->ys);
+				bat->xlast, bat->ylast, bp->xs, bp->ys);
 		}
 		XSetForeground(display, bp->backGC, bat->color);
 		XCopyPlane(display, bp->pixmap, window, bp->backGC,
@@ -253,18 +254,18 @@ drawbat(ModeInfo * mi, batstruct * bat)
 		XSetForeground(display, bp->backGC, bat->color);
 		if (bp->logo)
 			(void) XPutImage(display, window, bp->backGC, bp->logo,
-				 0, 0, bat->x, bat->y, bp->xs, bp->ys);
-	 	else
+				0, 0, bat->x, bat->y, bp->xs, bp->ys);
+		else
 /* PURIFY 4.0.1 on SunOS4 and on Solaris 2 reports a 15985 byte memory leak on
    * the next line. */
 			(void) XPutImage(display, window, bp->backGC,
-				 bp->images[(bat->orient > ORIENTS / 2) ?
+				bp->images[(bat->orient > ORIENTS / 2) ?
 					ORIENTS - bat->orient : bat->orient],
-				 0, 0, bat->x, bat->y, bp->xs, bp->ys);
+					0, 0, bat->x, bat->y, bp->xs, bp->ys);
 		if (bat->xlast != -1) {
 			XSetForeground(display, bp->backGC, bp->black);
 			ERASE_IMAGE(display, window, bp->backGC,
-				    bat->x, bat->y, bat->xlast, bat->ylast, bp->xs, bp->ys);
+				bat->x, bat->y, bat->xlast, bat->ylast, bp->xs, bp->ys);
 		}
 	}
 }
@@ -273,7 +274,7 @@ static void
 flapbat(batstruct * bat, int dir, int *vel, int avgsize)
 {
 	*vel -= (int) ((*vel + SIGN(*vel * dir) *
-		 bat->spindelay * ORIENTCYCLE / (M_PI * avgsize)) / SLIPAGE);
+			bat->spindelay * ORIENTCYCLE / (M_PI * avgsize)) / SLIPAGE);
 	if (*vel) {
 		bat->spindir = DIR(*vel * dir);
 		bat->vang = *vel * ORIENTCYCLE;
@@ -365,15 +366,21 @@ free_stuff(Display * display, bouncestruct * bp)
 	} else
 		bp->backGC = None;
 #endif
+#ifndef STANDALONE
+/* this used to work there I think */
 	if (bp->logo != None) {
 		destroyImage(&bp->logo, &bp->graphics_format);
 		bp->logo = None;
 	}
+#endif
 }
 
 static void
-free_bat(Display *display, bouncestruct *bp)
+free_bat_screen(Display *display, bouncestruct *bp)
 {
+	if (bp == NULL) {
+		return;
+	}
 	free_stuff(display, bp);
 	if (bp->bats != NULL) {
 		free(bp->bats);
@@ -383,7 +390,7 @@ free_bat(Display *display, bouncestruct *bp)
 		XFreePixmap(display, bp->pixmap);
 		bp->pixmap = None;
 	}
-
+	bp = NULL;
 }
 
 static Bool
@@ -394,20 +401,25 @@ init_stuff(ModeInfo * mi)
 	bouncestruct *bp = &bounces[MI_SCREEN(mi)];
 	int i;
 
+#ifndef STANDALONE
+/* this used to work there I think */
 	if (MI_BITMAP(mi) && strlen(MI_BITMAP(mi))) {
 		if (bp->logo == None) {
-                getImage(mi, &bp->logo, BAT_WIDTH, BAT_HEIGHT, BAT_BITS,
+			getImage(mi, &bp->logo, BAT_WIDTH, BAT_HEIGHT, BAT_BITS,
 #ifdef HAVE_XPM
-                         DEFAULT_XPM, BAT_NAME,
+				DEFAULT_XPM, BAT_NAME,
 #endif
-                         &bp->graphics_format, &bp->cmap, &bp->black);
+				&bp->graphics_format, &bp->cmap, &bp->black);
 			if (bp->logo == None) {
-				free_bat(display, bp);
+				free_bat_screen(display, bp);
 				return False;
 			}
 		}
-	} else {
-	if (!bp->cmap) {
+	} else
+#endif
+	{
+		if (bp->cmap == None) {
+/* problems here with XpmCreateImageFromData */
 #ifdef HAVE_XPM
 		int         total = 0;
 
@@ -418,7 +430,7 @@ init_stuff(ModeInfo * mi)
 			if (!fixedColors(mi)) {
 				if ((bp->cmap = XCreateColormap(display, window,
 						MI_VISUAL(mi), AllocNone)) == None) {
-					free_bat(display, bp);
+					free_bat_screen(display, bp);
 					return False;
 				}
 				attrib.colormap = bp->cmap;
@@ -433,7 +445,7 @@ init_stuff(ModeInfo * mi)
 
 			if (bp->graphics_format == IS_NONE
 #ifndef USE_MONOXPM
-			    && MI_NPIXELS(mi) > 2
+					&& MI_NPIXELS(mi) > 2
 #endif
 				) {
 				for (i = 0; i <= ORIENTS / 2; i++)
@@ -460,22 +472,20 @@ init_stuff(ModeInfo * mi)
 		}
 		if (total <= ORIENTS / 2)
 #endif
-
-		{
-			if (!bimages[0].data)	/* Only need to do this once */
-				for (i = 0; i <= ORIENTS / 2; i++) {
-					bimages[i].data = (char *) bits[i];
-					bimages[i].width = bat0_width;
-					bimages[i].height = bat0_height;
-					bimages[i].bytes_per_line = (bat0_width + 7) / 8;
-				}
-			for (i = 0; i <= ORIENTS / 2; i++)
-				bp->images[i] = &(bimages[i]);
+			{
+				if (!bimages[0].data)	/* Only need to do this once */
+					for (i = 0; i <= ORIENTS / 2; i++) {
+						bimages[i].data = (char *) bits[i];
+						bimages[i].width = bat0_width;
+						bimages[i].height = bat0_height;
+						bimages[i].bytes_per_line = (bat0_width + 7) / 8;
+					}
+				for (i = 0; i <= ORIENTS / 2; i++)
+					bp->images[i] = &(bimages[i]);
+			}
 		}
 	}
-  }
 	if (bp->cmap != None) {
-
 #ifndef STANDALONE
 		setColormap(display, window, bp->cmap, MI_IS_INWINDOW(mi));
 #endif
@@ -485,7 +495,7 @@ init_stuff(ModeInfo * mi)
 			xgcv.background = bp->black;
 			if ((bp->backGC = XCreateGC(display, window,
 					GCBackground, &xgcv)) == None) {
-				free_bat(display, bp);
+				free_bat_screen(display, bp);
 				return False;
 			}
 		}
@@ -496,7 +506,13 @@ init_stuff(ModeInfo * mi)
 	return True;
 }
 
-void
+ENTRYPOINT void
+free_bat(ModeInfo * mi)
+{
+	free_bat_screen(MI_DISPLAY(mi), &bounces[MI_SCREEN(mi)]);
+}
+
+ENTRYPOINT void
 init_bat(ModeInfo * mi)
 {
 	Display    *display = MI_DISPLAY(mi);
@@ -505,11 +521,7 @@ init_bat(ModeInfo * mi)
 	int         i, tryagain = 0;
 	bouncestruct *bp;
 
-	if (bounces == NULL) {
-		if ((bounces = (bouncestruct *) calloc(MI_NUM_SCREENS(mi),
-					     sizeof (bouncestruct))) == NULL)
-			return;
-	}
+	MI_INIT(mi, bounces);
 	bp = &bounces[MI_SCREEN(mi)];
 
 	free_stuff(display, bp);
@@ -534,15 +546,15 @@ init_bat(ModeInfo * mi)
 		bp->nbats = MINBATS;
 	if (!bp->bats) {
 		if ((bp->bats = (batstruct *) malloc(bp->nbats *
-				 sizeof (batstruct))) == NULL) {
-			free_bat(display, bp);
+					sizeof (batstruct))) == NULL) {
+			free_bat_screen(display, bp);
 			return;
 		}
 	}
 	if (!init_stuff(mi))
 		return;
 	if (size == 0 ||
-	    MINGRIDSIZE * size > bp->width / 2 || MINGRIDSIZE * size > bp->height) {
+			MINGRIDSIZE * size > bp->width / 2 || MINGRIDSIZE * size > bp->height) {
 		if (bp->logo) {
 			bp->xs = bp->logo->width;
 			bp->ys = bp->logo->height;
@@ -551,7 +563,7 @@ init_bat(ModeInfo * mi)
 			bp->ys = bat0_height;
 		}
 		if (bp->width > MINGRIDSIZE * bp->xs &&
-		    bp->height > MINGRIDSIZE * bp->ys) {
+				bp->height > MINGRIDSIZE * bp->ys) {
 			bp->pixelmode = False;
 		} else {
 			bp->pixelmode = True;
@@ -563,42 +575,42 @@ init_bat(ModeInfo * mi)
 		bp->pixelmode = True;
 		if (size < -MINSIZE)
 			bp->ys = NRAND(MIN(-size, MAX(MINSIZE, MIN(bp->width / 2, bp->height) /
-				      MINGRIDSIZE)) - MINSIZE + 1) + MINSIZE;
+				MINGRIDSIZE)) - MINSIZE + 1) + MINSIZE;
 		else if (size < MINSIZE)
 			bp->ys = MINSIZE;
 		else
 			bp->ys = MIN(size, MAX(MINSIZE, MIN(bp->width / 2, bp->height) /
-					       MINGRIDSIZE));
+				MINGRIDSIZE));
 		bp->xs = 2 * bp->ys;
 	}
 	bp->avgsize = (bp->xs + bp->ys) / 2;
 
-    if (bp->pixelmode) {
+	if (bp->pixelmode) {
 		GC fg_gc, bg_gc;
 		XGCValues gcv;
 
 		if ((bp->pixmap = XCreatePixmap(display, window, bp->xs, bp->ys, 1)) ==
 				None) {
-			free_bat(display, bp);
+			free_bat_screen(display, bp);
 			return;
 		}
 		gcv.foreground = 0;
 		gcv.background = 1;
 		if ((bg_gc = XCreateGC(display, bp->pixmap,
-				 GCForeground | GCBackground, &gcv)) == None) {
-			free_bat(display, bp);
+				GCForeground | GCBackground, &gcv)) == None) {
+			free_bat_screen(display, bp);
 			return;
 		}
 		gcv.background = 0;
 		gcv.foreground = 1;
 		if ((fg_gc = XCreateGC(display, bp->pixmap,
-				 GCForeground | GCBackground, &gcv)) == None) {
+				GCForeground | GCBackground, &gcv)) == None) {
 			XFreeGC(display, bg_gc);
-			free_bat(display, bp);
+			free_bat_screen(display, bp);
 			return;
 		}
 		XFillRectangle(display, bp->pixmap, bg_gc,
-	   		0, 0, bp->xs, bp->ys);
+			0, 0, bp->xs, bp->ys);
 		XFillArc(display, bp->pixmap, fg_gc,
 			0, 0, bp->xs / 2, 2 * bp->ys,
 			0, 11520);
@@ -607,7 +619,7 @@ init_bat(ModeInfo * mi)
 			0, 11520);
 		XFillRectangle(display, bp->pixmap, fg_gc,
 			bp->xs / 4, bp->ys / 2,
-	        bp->xs / 2, bp->ys / 2);
+			bp->xs / 2, bp->ys / 2);
 		XFillArc(display, bp->pixmap, bg_gc,
 			0, bp->ys / 2, bp->xs / 2, 2 * bp->ys,
 			0, 11520);
@@ -644,14 +656,14 @@ init_bat(ModeInfo * mi)
 			tryagain++;
 	}
 	/* don't want any exposure events from XCopyPlane */
-    XSetGraphicsExposures(display, MI_GC(mi), False);
+	XSetGraphicsExposures(display, MI_GC(mi), False);
 	MI_CLEARWINDOWCOLORMAP(mi, bp->backGC, bp->black);
 }
 
-void
+ENTRYPOINT void
 draw_bat(ModeInfo * mi)
 {
-	int           i;
+	int         i;
 	bouncestruct *bp;
 
 	if (bounces == NULL)
@@ -673,20 +685,21 @@ draw_bat(ModeInfo * mi)
 		init_bat(mi);
 }
 
-void
+ENTRYPOINT void
 release_bat(ModeInfo * mi)
 {
 	if (bounces != NULL) {
 		int        screen;
 
 		for (screen = 0; screen < MI_NUM_SCREENS(mi); screen++)
-			free_bat(MI_DISPLAY(mi), &bounces[screen]);
+			free_bat_screen(MI_DISPLAY(mi), &bounces[screen]);
 		free(bounces);
 		bounces = (bouncestruct *) NULL;
 	}
 }
 
-void
+#ifndef STANDALONE
+ENTRYPOINT void
 refresh_bat(ModeInfo * mi)
 {
 	bouncestruct *bp;
@@ -710,5 +723,8 @@ refresh_bat(ModeInfo * mi)
 	MI_CLEARWINDOWCOLORMAP(mi, bp->backGC, bp->black);
 #endif
 }
+#endif
+
+XSCREENSAVER_MODULE ("Bat", bat)
 
 #endif /* MODE_bat */
